@@ -18,6 +18,7 @@ read_next <- function(x, timeout = 3000) {
 }
 
 has_locale <- function(l) {
+  skip_if_not_installed("withr")
   has <- TRUE
   tryCatch(
     withr::with_locale(c(LC_CTYPE = l), "foobar"),
@@ -99,6 +100,7 @@ test_paths <- function(callr_drop, callr_keep,
 
 test_temp_file <- function(fileext = "", pattern = "test-file-",
                            envir = parent.frame(), create = TRUE) {
+  skip_if_not_installed("withr")
   tmp <- tempfile(pattern = pattern, fileext = fileext)
   if (identical(envir, .GlobalEnv)) {
     message("Temporary files will _not_ be cleaned up")
@@ -126,6 +128,7 @@ expect_error <- function(..., class = "error") {
 }
 
 test_package_root <- function() {
+  skip_if_not_installed("rprojroot")
   x <- tryCatch(
     rprojroot::find_package_root_file(),
     error = function(e) NULL)
@@ -159,3 +162,49 @@ without_env <- function(f) {
   environment(f) <- .GlobalEnv
   f
 }
+
+expect_r_process_snapshot <- function(..., interactive = TRUE, echo = TRUE,
+                                      transform = NULL, variant = NULL) {
+  skip_if_not_installed("asciicast")
+  skip_if_not_installed("withr")
+
+  # Skip these tests on platforms where V8 is not available
+  if (! R.Version()$arch %in% c("i386", "x86_64", "aarch64") &&
+                   ! requireNamespace("asciicast", quietly = TRUE)) {
+    skip("No asciicast package")
+  }
+
+  # errors.R assumes non-interactive in testthat, but we don't want that
+  withr::local_envvar(TESTTHAT = NA_character_)
+  dots <- eval(substitute(alist(...)))
+  nms <- names(dots)
+  if (all(nms == "")) {
+    code_pos <- rep(TRUE, length(dots))
+  } else {
+    code_pos <- nms == ""
+  }
+  code <- unlist(lapply(dots[code_pos], deparse))
+  args <- dots[!code_pos]
+
+  record_output <- asciicast::record_output
+  output <- do.call(
+    "record_output",
+    c(list(code), args, interactive = interactive, echo = echo)
+  )
+
+  r_process <- function() writeLines(output)
+
+  expect_snapshot(r_process(), transform = transform, variant = variant)
+}
+
+redact_srcref <- function(x) {
+  sub("[ ]*at [-a-zA-Z0-9]+[.]R:[0-9]+:[0-9]+?", "", x)
+}
+
+redact_callr_rs_result <- function(x) {
+  sub("done callr-rs-result-[a-f0-9]+", "done callr-rs-result-<id>", x)
+}
+
+fix_eol <- function(x) {
+  gsub("\\r\\n", "\\n", x, fixed = TRUE)
+}
