@@ -1,6 +1,4 @@
 
-context("library path setup")
-
 test_that(".Library", {
   expect_equal(
     .Library,
@@ -18,6 +16,7 @@ test_that(".Library.site", {
 })
 
 test_that(".libPaths()", {
+  skip_if_not_installed("withr")
   dir.create(tmp <- tempfile())
   on.exit(unlink(tmp, recursive = TRUE))
 
@@ -37,6 +36,7 @@ test_that("if .Renviron overrides R_PROFILE", {
   ## But we still need to use the proper lib path, as set in the fake
   ## profile
   skip_in_covr()
+  skip_if_not_installed("withr")
 
   cat("Sys.setenv(FOO='nope')\n", file = tmp_prof <- tempfile())
   cat("R_PROFILE=\"", tmp_prof, "\"\n", file = tmp_env <- tempfile(), sep = "")
@@ -66,6 +66,7 @@ test_that("libpath in system(), empty .Renviron", {
   # We remove the library with covr from the lib path, so this
   # cannot work in a subprocess.
   skip_in_covr()
+  skip_if_not_installed("withr")
 
   dir.create(tmpdrop <- tempfile("drop"))
   dir.create(tmpkeep <- tempfile("keep"))
@@ -88,6 +89,7 @@ test_that("libpath in system, R_LIBS in .Renviron", {
   # We remove the library with covr from the lib path, so this
   # cannot work in a subprocess.
   skip_in_covr()
+  skip_if_not_installed("withr")
 
   dir.create(tmpdrop <- tempfile("drop"))
   dir.create(tmpkeep <- tempfile("keep"))
@@ -111,6 +113,7 @@ test_that("libpath in system, R_LIBS", {
   # We remove the library with covr from the lib path, so this
   # cannot work in a subprocess.
   skip_in_covr()
+  skip_if_not_installed("withr")
 
   dir.create(tmpdrop <- tempfile("drop"))
   dir.create(tmpkeep <- tempfile("keep"))
@@ -134,6 +137,7 @@ test_that("libpath in system, R_LIBS and .Renviron", {
   # We remove the library with covr from the lib path, so this
   # cannot work in a subprocess.
   skip_in_covr()
+  skip_if_not_installed("withr")
 
   dir.create(tmpdrop <- tempfile("drop"))
   dir.create(tmpkeep <- tempfile("keep"))
