@@ -1,6 +1,4 @@
 
-context("rcmd")
-
 test_that("rcmd works", {
   expect_equal(rcmd("config", "CC")$status, 0)
   expect_match(rcmd("config", "CC")$stdout, ".")
@@ -13,6 +11,8 @@ test_that("rcmd show works", {
 })
 
 test_that("rcmd echo works", {
+  skip_if_not_installed("withr")
+  withr::local_options(width = 500)
   expect_output(rcmd("config", "CC", echo = TRUE), "config\\s+CC")
   gc()
 })
@@ -40,6 +40,7 @@ test_that("wd argument", {
 })
 
 test_that("fail_on_status", {
+  skip_if_not_installed("withr")
   rand <- tempfile()
   expect_error(
     withr::with_dir(
@@ -77,7 +78,7 @@ test_that("stderr -> stdout", {
   expect_match(
     out2$stdout,
     "installing.*No man pages found.*testing if installed package")
-  expect_equal(out2$stderr, "")
+  expect_null(out2$stderr)
 
   out3 <- test_temp_file(create = FALSE)
   rcmd("INSTALL", c("-l", lib, pkg), stdout = out3, stderr = out3)
